from fastspider.commands.cmdline import execute


def main():
	execute()


if __name__ == '__main__':
	main()
